@@ -25,17 +25,15 @@ import json
 
 
 name = 'matrixpy'
-__version__ = '0.4'
-__all__     = ['Matrix']
+__version__ = '0.5.1'
+__all__     = ['Matrix', 'MatrixError']
 
 
 class MatrixError(Exception):
-
     """Error for the Matrix Object invalid operations"""
 
 
 class Matrix:
-
     """Matrix Object: add, sub, mul, and a lot more"""
 
     # Object Creation: START
@@ -46,7 +44,7 @@ class Matrix:
 
         # Matrix(3) -> (3x3) Zero Matrix
         if isinstance(matrix, int):
-            self.matrix = Matrix.identity(matrix).to_list()
+            self.matrix = Matrix.identity(matrix).tolist()
 
         # Matrix("1 2 3; 4 5 6") -> Row1 = (1 2 3), Row2 = (4 5 6)
         if isinstance(matrix, str):
@@ -57,7 +55,7 @@ class Matrix:
                 matrix[i] = nums.split(' ')
 
             # list From str -> int
-            self.matrix = [list(map(int, matrix[i])) 
+            self.matrix = [list(map(int, matrix[i]))
             for i in range(len(matrix))]
 
         self.rowsnum = len(self.matrix)
@@ -67,7 +65,7 @@ class Matrix:
         """Returnt the matrix in string formatted way"""
         result = list()
 
-        ma_str = [list(map(str, self.matrix[i])) 
+        ma_str = [list(map(str, self.matrix[i]))
         for i in range(self.rowsnum)]
 
         for i in ma_str:
@@ -134,7 +132,7 @@ class Matrix:
             if (self.rowsnum != other.rowsnum or
                 self.colsnum != other.colsnum):
                 raise MatrixError('To add matrices, the matrices must have'
-                ' the same dimensions')
+                ' the same dimensions') from None
 
             for m in range(self.rowsnum):
                 result.append([])
@@ -161,7 +159,7 @@ class Matrix:
             if (self.rowsnum != other.rowsnum or
                 self.colsnum != other.colsnum):
                 raise MatrixError('To sub matrices, the matrices must have'
-                ' the same dimensions')
+                ' the same dimensions') from None
 
             for m in range(self.rowsnum):
                 result.append([])
@@ -184,7 +182,7 @@ class Matrix:
             # A * B
             if self.colsnum != other.rowsnum:
                 raise MatrixError('The number of rows in matrix A must be'
-                ' equal to the number of columns in B matrix')
+                ' equal to the number of columns in B matrix') from None
 
             # References:
             # https://www.geeksforgeeks.org/python-program-multiply-two-matrices
@@ -205,39 +203,41 @@ class Matrix:
 
     # Object Manpulation: START
     def row(self, num: int, start=0):
-        if num <= start-1: raise MatrixError('The matrix rows start from'
-        f' {start} row(num) to start from 0')
-        if num > start-1: num -= start
+        """Return the given row position"""
+        if num > start-1:
+            num -= start
 
         try:
             return Matrix([self.matrix[num]])
         except IndexError:
-            raise MatrixError('Matrix Index out of range')
+            raise MatrixError('Matrix Index out of range') from None
 
 
     def col(self, num: int, start=0):
-        if num <= start-1: raise MatrixError('The matrix cols start from'
-        f' {start} col(num) to start from 0')
-        if num > start-1: num -= start
+        """Return the given col position"""
+        if num > start-1:
+            num -= start
 
         try:
             return Matrix([[row[num]] for row in self.matrix])
         except IndexError:
-            raise MatrixError('Matrix Index out of range')
+            raise MatrixError('Matrix Index out of range') from None
 
 
     def addrow(self, row, index=-1):
+        """Add a row to an exisiting Matrix object"""
         result = self.matrix
 
         if index == -1:
-            result.insert(self.rowsnum, (Matrix(row).to_list()[0]))
+            result.insert(self.rowsnum, (Matrix(row).tolist()[0]))
         else:
-            result.insert(index, (Matrix(row).to_list()[0]))
+            result.insert(index, (Matrix(row).tolist()[0]))
 
         return Matrix(result)
 
 
     def addcol(self, col, index=-1):
+        """Add a col to an exisiting Matrix object"""
         result = self.matrix
 
         if index == -1:
@@ -251,35 +251,36 @@ class Matrix:
 
 
     def rmrow(self, index):
+        """Remove a row from an exisiting Matrix object"""
         result = self.matrix
 
         try:
             result.pop(index)
         except IndexError:
-            raise MatrixError("Matrix index out of range")
+            raise MatrixError("Matrix index out of range") from None
 
         return Matrix(result)
 
-    
+
     def rmcol(self, index):
+        """Remove a col from an exisiting Matrix object"""
         result = self.matrix
 
         try:
             for i in range(self.rowsnum):
                 result[i].pop(index)
         except IndexError:
-            raise MatrixError("Matrix index out of range")
+            raise MatrixError("Matrix index out of range") from None
 
         return Matrix(result)
 
 
     def transpose(self: list):
         """Return a new matrix transposed"""
-        result = [list(i) for i in zip(*self.matrix)]
-        return Matrix(result)
+        return Matrix([list(i) for i in zip(*self.matrix)])
 
 
-    def to_list(self):
+    def tolist(self):
         """Convert Matrix object to a list"""
         return self.matrix
     # Object Manpulation: END
@@ -287,15 +288,12 @@ class Matrix:
     # Booleon Expressions: START
     def is_square(self):
         """Check if the matrix is square"""
-        if self.rowsnum == self.colsnum:
-            return True
-        else:
-            return False
+        return bool(self.rowsnum == self.colsnum)
 
 
     def is_symmetric(self):
         """Check of the matrix is symmetric"""
-        if self.matrix == (Matrix(self.matrix).transpose()).to_list():
+        if self.matrix == (Matrix(self.matrix).transpose()).tolist():
             return True
         return False
     # Booleon Expressions: END
@@ -335,6 +333,7 @@ class Matrix:
 def main():
     """The CLI for the module"""
     parser=argparse.ArgumentParser(
+        prog="matrix-py",
         description = 'matrix-py module to add, substract, multiply'
         'matrices.',
         epilog = 'Usage: .. -ma "[[1, 2, 3], [4, 5, 6]]" -op "+" -mb'
